summaryrefslogtreecommitdiffstats
path: root/libkdeedu/kdeeduplot
diff options
context:
space:
mode:
Diffstat (limited to 'libkdeedu/kdeeduplot')
-rw-r--r--libkdeedu/kdeeduplot/kplotwidget.cpp2
-rw-r--r--libkdeedu/kdeeduplot/kplotwidget.h10
2 files changed, 6 insertions, 6 deletions
diff --git a/libkdeedu/kdeeduplot/kplotwidget.cpp b/libkdeedu/kdeeduplot/kplotwidget.cpp
index 321dd444..99e9b321 100644
--- a/libkdeedu/kdeeduplot/kplotwidget.cpp
+++ b/libkdeedu/kdeeduplot/kplotwidget.cpp
@@ -223,7 +223,7 @@ void KPlotWidget::drawObjects( TQPainter *p ) {
double KPlotWidget::dmod( double a, double b ) { return ( b * ( ( a / b ) - int( a / b ) ) ); }
void KPlotWidget::drawBox( TQPainter *p ) {
- //First, fill in padding region with bgColor() to tqmask out-of-bounds plot data
+ //First, fill in padding region with bgColor() to mask out-of-bounds plot data
p->setPen( bgColor() );
p->setBrush( bgColor() );
diff --git a/libkdeedu/kdeeduplot/kplotwidget.h b/libkdeedu/kdeeduplot/kplotwidget.h
index 212c5234..5ed550ec 100644
--- a/libkdeedu/kdeeduplot/kplotwidget.h
+++ b/libkdeedu/kdeeduplot/kplotwidget.h
@@ -95,11 +95,11 @@ public:
*/
virtual void clearObjectList() { ObjectList.clear(); update(); }
/**@short tqreplace an item in the KPlotObject list.
*@param i the index of th item to be tqreplaced
*@param o pointer to the tqreplacement KPlotObject
*/
- virtual void tqreplaceObject( int i, KPlotObject *o ) { ObjectList.tqreplace( i, o ); }
+ virtual void replaceObject( int i, KPlotObject *o ) { ObjectList.replace( i, o ); }
/**@return the number of KPlotObjects in the list
*/
@@ -212,7 +212,7 @@ public:
KPlotAxis LeftAxis;
protected:
- /**@short the paint event handler, executed when update() or tqrepaint() is called.
+ /**@short the paint event handler, executed when update() or repaint() is called.
*/
virtual void paintEvent( TQPaintEvent* /* e */ );
@@ -95,11 +95,11 @@ public:
*/
virtual void clearObjectList() { ObjectList.clear(); update(); }
- /**@short tqreplace an item in the KPlotObject list.
- *@param i the index of th item to be tqreplaced
- *@param o pointer to the tqreplacement KPlotObject
+ /**@short replace an item in the KPlotObject list.
+ *@param i the index of th item to be replaced
+ *@param o pointer to the replacement KPlotObject
*/